Type: Package
Package: colleyRstats
Title: Functions to Streamline Statistical Analysis and Reporting
Version: 0.2.0
Authors@R: 
    person("Mark", "Colley", , "mark.colley@yahoo.de", role = c("aut", "cre", "cph"), comment = c(ORCID = "0000-0001-5207-5029"))
Description: Built upon popular R packages such as 'ggstatsplot' and 'ARTool', this collection offers a wide array of tools for simplifying reproducible analyses, generating high-quality visualizations, and producing 'APA'-compliant outputs. The primary goal of this package is to significantly reduce repetitive coding efforts, allowing you to focus on interpreting results. Whether you're dealing with ANOVA assumptions, reporting effect sizes, or creating publication-ready visualizations, this package makes these tasks easier.
URL: https://github.com/M-Colley/colleyRstats,
        https://m-colley.github.io/colleyRstats/
BugReports: https://github.com/M-Colley/colleyRstats/issues
License: MIT + file LICENSE
Encoding: UTF-8
Language: en-US
Depends: R (>= 4.2.0), ggplot2 (>= 3.4.0)
Imports: dplyr (>= 1.1.0), effectsize, ggpmisc (>= 0.5.0), ggsignif,
        ggstatsplot (>= 1.0.0), grid, lifecycle, purrr, rlang, see,
        stats, statsExpressions (>= 2.0.0), stringr, tidyr, utils
Suggests: afex, ARTool (>= 0.11.0), av, BayesFactor, bayestestR, Cairo,
        car, clipr, conflicted, DT, dunn.test, easystats, emmeans,
        emoa, flexdashboard, FSA, ggtext, glmmTMB, Hmisc, knitr, lme4,
        lmerTest, moocore, nnet, nparLD, ordinal, parameters,
        patchwork, pkgload, psych, readxl, renv, report, reporttools,
        rmarkdown, rstantools, rstatix, scales, sjPlot, stargazer,
        styler, testthat (>= 3.3.0), tibble, withr, writexl, xtable
Config/testthat/edition: 3
Config/Needs/check: anthonynorth/roxyglobals
Config/roxyglobals/unique: TRUE
Config/testthat/parallel: false
VignetteBuilder: knitr
Config/roxygen2/version: 8.1.0
NeedsCompilation: no
Packaged: 2026-09-01 16:16:41 UTC; Mark
Author: Mark Colley [aut, cre, cph] (ORCID:
    <https://orcid.org/0000-0001-5207-5029>)
Maintainer: Mark Colley <mark.colley@yahoo.de>
Repository: CRAN
Date/Publication: 2026-09-02 12:50:02 UTC
Built: R 4.6.0; ; 2026-09-02 15:03:54 UTC; unix
