# Generated by roxygen2: do not edit by hand

S3method(print,colley_fit)
S3method(print,colley_recommendation)
export("%!in%")
export(add_pareto_emoa_column)
export(add_pareto_moocore_column)
export(analyze_and_report)
export(animate_mobo2)
export(assumption_methods_text)
export(checkAssumptionsForAnova)
export(check_assumptions_anova)
export(check_homogeneity_by_group)
export(check_normality_by_group)
export(check_questionnaire)
export(cite_methods)
export(classify_outcome)
export(colleyRstats_setup)
export(colley_theme)
export(debug_contr_error)
export(define_questionnaire)
export(define_result_macro)
export(emit_name_macros)
export(emit_overleaf)
export(expand_latex_macros)
export(figure_base_size)
export(fit_recommended)
export(generateEffectPlot)
export(generateMoboPlot)
export(generateMoboPlot2)
export(ggbetweenstatsWithPriorNormalityCheck)
export(ggbetweenstatsWithPriorNormalityCheckAsterisk)
export(ggwithinstatsWithPriorNormalityCheck)
export(ggwithinstatsWithPriorNormalityCheckAsterisk)
export(latex_escape)
export(latex_preamble)
export(latexify_report)
export(list_questionnaires)
export(n_fun)
export(na.zero)
export(normalize)
export(not_empty)
export(not_in)
export(pathPrep)
export(plot_between_stats)
export(plot_between_stats_asterisk)
export(plot_effect)
export(plot_mobo)
export(plot_mobo2)
export(plot_within_stats)
export(plot_within_stats_asterisk)
export(questionnaire_items)
export(rFromNPAV)
export(rFromWilcox)
export(rFromWilcoxAdjusted)
export(recommend_analysis)
export(recommend_test)
export(remove_outliers_REI)
export(replace_values)
export(reportART)
export(reportArtCon)
export(reportArtConTable)
export(reportCLMM)
export(reportDunnTest)
export(reportDunnTestTable)
export(reportGLMM)
export(reportMeanAndSD)
export(reportNPAV)
export(reportNparLD)
export(report_all)
export(report_art)
export(report_art_con)
export(report_art_con_table)
export(report_clmm)
export(report_dunn_test)
export(report_dunn_test_table)
export(report_ggstatsplot)
export(report_ggstatsplot_posthoc)
export(report_glmm)
export(report_mean_sd)
export(report_nparld)
export(reportggstatsplot)
export(reportggstatsplotPostHoc)
export(reshape_data)
export(reverse_code)
export(save_paper_figure)
export(score_questionnaire)
export(score_reliability)
export(stat_sum_df)
export(summarize_sickness)
export(use_colleyrstats_sty)
export(use_study_project)
import(ggplot2)
import(ggpmisc)
importFrom(dplyr,
  across,
  all_of,
  arrange,
  bind_cols,
  bind_rows,
  case_when,
  filter,
  group_by,
  mutate,
  select,
  summarise
)
importFrom(ggstatsplot,
  extract_stats,
  ggbetweenstats,
  ggwithinstats
)
importFrom(rlang,sym)
importFrom(see,
  scale_color_see,
  scale_colour_see,
  scale_fill_see
)
importFrom(stats,
  as.formula,
  lm,
  median,
  pnorm,
  qnorm,
  residuals,
  sd,
  setNames,
  shapiro.test
)
importFrom(stringr,
  str_detect,
  str_split
)
importFrom(tidyr,drop_na)
importFrom(utils,globalVariables)
