#' @importFrom dplyr filter select mutate group_by summarise across all_of bind_cols bind_rows arrange
#' @import ggplot2
#' @import ggpmisc
#' @importFrom rlang sym
#' @importFrom stats as.formula lm median pnorm qnorm residuals sd shapiro.test setNames
#' @importFrom utils globalVariables
#' @importFrom see scale_color_see scale_fill_see scale_colour_see
#' @importFrom stringr str_detect str_split
#' @importFrom clipr write_clip
#' @importFrom tidyr drop_na
#' @importFrom rstatix levene_test shapiro_test
#' @importFrom ggtext element_markdown
#' @importFrom ggstatsplot ggbetweenstats ggwithinstats extract_stats
#' @importFrom ARTool art
#' @importFrom report report
NULL
