utils::globalVariables(c(
  "ConditionID", "p.value", "p-adjusted", "statistic", "estimate",
  "df.error", "Comparison", "Z", "group1", "group2",
  "asterisk_label", "group_all_data_equal", "phaseCol",
  "REI", "Suspicious", "Percentile", "PARETO_EMOA",
  "x", "y", "df", "sd"
))
